/*
 * @Author: wangming
 * @Date: 2020-06-26 21:53:27
 * @LastEditors: wangming
 * @LastEditTime: 2020-07-29 20:57:32
 * @Description: file content
 */

import Vue from 'vue';
import router from './router';
import store from './store';

import NProgress from 'nprogress'; // progress bar
import '@/components/NProgress/nprogress.less'; // progress bar custom style
import notification from 'ant-design-vue/es/notification';
import { setDocumentTitle, domTitle } from '@/utils/domUtil';
import { ACCESS_TOKEN } from '@/store/mutation-types';
NProgress.configure({
	showSpinner: false
}); // NProgress Configuration
const whiteList = ['/sso', '/login', '/user/login']; // no redirect whitelist
const defaultRoutePath = '/dashboard';
router.beforeEach((to, from, next) => {
	NProgress.start(); // start progress bar
	to.meta && typeof to.meta.title !== 'undefined' && setDocumentTitle(`${to.meta.title} - ${domTitle}`);
	to.query.newtimet = new Date().getTime();
	console.log('before router', to);
	console.log('store.getters.roles', store.getters.roles);
	if (Vue.ls.get(ACCESS_TOKEN)) {
		console.log('p 0');
		/* has token */
		if (to.path === '/user/login' || to.path === '/login' || to.path === '/sso') {
			next({
				path: defaultRoutePath
			});
			NProgress.done();
		} else if (store.getters.roles.length === 0) {
			console.log('p 1');
			store
				.dispatch('GetInfo')
				.then(res => {
					const roles = res.result && res.result.role;
					store.dispatch('GenerateRoutes', { roles }).then(() => {
						// 根据roles权限生成可访问的路由表
						// 动态添加可访问路由表
						router.addRoutes(store.getters.addRouters);
						const redirect = decodeURIComponent(from.query.redirect || to.path);

						if (to.path === redirect) {
							// hack方法 确保addRoutes已完成 ,set the replace: true so the navigation will not leave a history record
							next({
								...to,
								replace: true
							});
						} else {
							// 跳转到目的路由
							next({
								path: redirect
							});
						}
					});
				})
				.catch(() => {
					notification.error({
						message: '错误',
						description: '请求用户信息失败，请重试'
					});
					store.dispatch('Logout').then(() => {
						next({
							path: '/user/login',
							query: {
								redirect: to.fullPath
							}
						});
					});
				});
		} else {
			console.log('p 2');
			next();
			// let m = sessionStorage.getItem('menuList') || '[]';
			// let menuInfo = JSON.parse(m);
			// if (menuInfo.indexOf(to.name) > -1) {
			// 	console.log('p 3');
			// 	next();
			// } else {
			// 	console.log('p 4');
			// 	next();
			// }
		}
	} else if (whiteList.includes(to.path)) {
		console.log('route whiteList');
		// 在免登录白名单，直接进入
		next();
		// NProgress.done();
	} else {
		console.log('route without login');
		next({
			path: process.env.VUE_APP_DDLogin == 1 ? '/sso' : '/login'
		});
		NProgress.done(); // if current page is login will not trigger afterEach hook, so manually handle it
	}
});

router.afterEach(() => {
	NProgress.done(); // finish progress bar
});
